@@ -29,7 +29,7 @@ import os
 from typing import *
 
 import typedload
-import xtermcolor
+import termcolor
 
 
 VERSION = '1.2'
@@ -153,7 +153,7 @@ class WikiTab(NamedTuple):
         content = self.content
         for i in self.get_tokens(transpose):
             if isinstance(i, Chord):
-                print(xtermcolor.colorize(i, 0x00FF00), end='')
+                termcolor.cprint(i, 'green', end='')
             else:
                 i = i.replace('[tab]', '').replace('[/tab]', '')
                 print(i, end='')
